# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: magpie.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='magpie.proto',
  package='magpie',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cmagpie.proto\x12\x06magpie\"\x17\n\x04Ping\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x17\n\x04Pong\x12\x0f\n\x07message\x18\x01 \x01(\t\"\'\n\x17UpdateRefDataFromQC_Msg\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x1a\n\tNoneReply\x12\r\n\x05reply\x18\x01 \x01(\t2~\n\x06Magpie\x12)\n\x0bHealthCheck\x12\x0c.magpie.Ping\x1a\x0c.magpie.Pong\x12I\n\x13UpdateRefDataFromQC\x12\x1f.magpie.UpdateRefDataFromQC_Msg\x1a\x11.magpie.NoneReplyb\x06proto3'
)




_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='magpie.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='magpie.Ping.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=47,
)


_PONG = _descriptor.Descriptor(
  name='Pong',
  full_name='magpie.Pong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='magpie.Pong.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=72,
)


_UPDATEREFDATAFROMQC_MSG = _descriptor.Descriptor(
  name='UpdateRefDataFromQC_Msg',
  full_name='magpie.UpdateRefDataFromQC_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='magpie.UpdateRefDataFromQC_Msg.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=113,
)


_NONEREPLY = _descriptor.Descriptor(
  name='NoneReply',
  full_name='magpie.NoneReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply', full_name='magpie.NoneReply.reply', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Pong'] = _PONG
DESCRIPTOR.message_types_by_name['UpdateRefDataFromQC_Msg'] = _UPDATEREFDATAFROMQC_MSG
DESCRIPTOR.message_types_by_name['NoneReply'] = _NONEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'magpie_pb2'
  # @@protoc_insertion_point(class_scope:magpie.Ping)
  })
_sym_db.RegisterMessage(Ping)

Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), {
  'DESCRIPTOR' : _PONG,
  '__module__' : 'magpie_pb2'
  # @@protoc_insertion_point(class_scope:magpie.Pong)
  })
_sym_db.RegisterMessage(Pong)

UpdateRefDataFromQC_Msg = _reflection.GeneratedProtocolMessageType('UpdateRefDataFromQC_Msg', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREFDATAFROMQC_MSG,
  '__module__' : 'magpie_pb2'
  # @@protoc_insertion_point(class_scope:magpie.UpdateRefDataFromQC_Msg)
  })
_sym_db.RegisterMessage(UpdateRefDataFromQC_Msg)

NoneReply = _reflection.GeneratedProtocolMessageType('NoneReply', (_message.Message,), {
  'DESCRIPTOR' : _NONEREPLY,
  '__module__' : 'magpie_pb2'
  # @@protoc_insertion_point(class_scope:magpie.NoneReply)
  })
_sym_db.RegisterMessage(NoneReply)



_MAGPIE = _descriptor.ServiceDescriptor(
  name='Magpie',
  full_name='magpie.Magpie',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=143,
  serialized_end=269,
  methods=[
  _descriptor.MethodDescriptor(
    name='HealthCheck',
    full_name='magpie.Magpie.HealthCheck',
    index=0,
    containing_service=None,
    input_type=_PING,
    output_type=_PONG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRefDataFromQC',
    full_name='magpie.Magpie.UpdateRefDataFromQC',
    index=1,
    containing_service=None,
    input_type=_UPDATEREFDATAFROMQC_MSG,
    output_type=_NONEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MAGPIE)

DESCRIPTOR.services_by_name['Magpie'] = _MAGPIE

# @@protoc_insertion_point(module_scope)
